==> gateau-0.1.2.tgz: package/es/Main.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import R from 'ramda';
import React from 'react';
import { findDOMNode } from 'react-dom';
import seeds, { Seed } from 'react-seeds';
import { action } from 'mobx';
import { observer } from 'mobx-react';

import destinations from './destinations';

import * as colors from './colors';
import * as stylers from './stylers';
import Button from './ui/Button';
import Field from './ui/Field';
import Choice from './ui/Choice';
import IngredientsEditor from './sections/IngredientsEditor';
import PreviewSection from './sections/preview';

import createObservableState from './state';

export default observer(React.createClass({
	getDefaultProps: function getDefaultProps() {
		return {
			showTree: false,
			initialDestinationID: 'foundation',
			initialDestinationDevice: 'phone'
		};
	},
	componentWillMount: function componentWillMount() {
		var _this = this;

		var _props = this.props,
		    content = _props.initialContent,
		    allIngredients = _props.initialIngredients,
		    destinationID = _props.initialDestinationID,
		    destinationDevice = _props.initialDestinationDevice,
		    scenarios = _props.initialScenarios,
		    _props$initialActiveS = _props.initialActiveScenarioIndex,
		    activeScenarioIndex = _props$initialActiveS === undefined ? 0 : _props$initialActiveS;


		createObservableState.call(this, {
			content: content,
			allIngredients: allIngredients,
			scenarios: scenarios,
			activeScenarioIndex: activeScenarioIndex,
			destinationID: destinationID,
			destinationDevice: destinationDevice
		});

		this.onSourceChange = action(function (input) {
			_this.content = input;
		});
		this.onChangeDestination = action(function (newDestinationID) {
			_this.destinationID = newDestinationID;
		});
		this.onPhoneDestination = action(function () {
			_this.destinationDevice = 'phone';
		});
		this.onFullDestination = action(function () {
			_this.destinationDevice = 'full';
		});
	},
	onClickDrag: function onClickDrag(_ref) {
		var type = _ref.type,
		    currentTarget = _ref.currentTarget,
		    target = _ref.target,
		    clientX = _ref.clientX;

		if (type == 'mouseup') {
			this.dragging = false;
		} else if (this.dragging || type == 'mousedown') {
			if (type == 'mousemove') {
				currentTarget.scrollLeft += this.mouseX - clientX;
			}

			if (type == 'mouseup') {
				this.dragging = false;
			} else {
				// Only allow clicking on background
				if (target.tagName == 'DIV') {
					this.dragging = true;
					this.mouseX = clientX;
				}
			}
		}
	},
	render: function render() {
		var showTree = this.props.showTree;
		var content = this.content,
		    contentTree = this.contentTree,
		    allIngredients = this.allIngredients,
		    activeIngredients = this.activeIngredients,
		    scenarios = this.scenarios,
		    activeScenarioIndex = this.activeScenarioIndex,
		    destinationID = this.destinationID,
		    destinationDevice = this.destinationDevice;


		var scenario = scenarios[activeScenarioIndex];

		console.dir(scenario);
		console.dir(contentTree);
		console.dir(activeIngredients);

		return React.createElement(
			Seed,
			{ row: true, justifyContent: 'center',
				grow: 0, shrink: 0,
				background: { color: '#191919' }
			},
			React.createElement(
				Seed,
				{ row: true,
					grow: 1, shrink: 2,
					minWidth: 320,
					overflow: 'scroll',
					onMouseDown: this.onClickDrag,
					onMouseMove: this.onClickDrag,
					onMouseUp: this.onClickDrag
				},
				React.createElement(
					Seed,
					_extends({ column: true,
						grow: 1
					}, stylers.mainColumn),
					React.createElement(Field, _extends({
						value: content,
						onChange: this.onSourceChange
					}, stylers.sourceField))
				),
				React.createElement(
					Seed,
					{ column: true },
					React.createElement(IngredientsEditor, {
						ingredients: allIngredients,
						ingredientIDToVariationIndex: scenario,
						onAddNew: this.addNewIngredient,
						onRemoveAtIndex: this.onRemoveIngredientAtIndex,
						onAddVariationAtIndex: this.onAddVariationAtIndex
					})
				)
			),
			showTree && React.createElement(
				Seed,
				_extends({ row: true, grow: 1, shrink: 1
				}, stylers.preview),
				React.createElement(
					'pre',
					null,
					!!contentTree ? JSON.stringify(contentTree, null, 2) : null
				)
			),
			React.createElement(PreviewSection, {
				contentTree: contentTree,
				ingredients: activeIngredients,
				destinationID: destinationID,
				destinationDevice: destinationDevice,
				destinations: destinations,
				onChangeDestination: this.onChangeDestination,
				onPhoneDestination: this.onPhoneDestination,
				onFullDestination: this.onFullDestination
			})
		);
	}
}));

==> gateau-0.1.5.tgz: package/es/Main.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import R from 'ramda';
import React from 'react';
import { findDOMNode } from 'react-dom';
import seeds, { Seed } from 'react-seeds';
import { action, autorunAsync } from 'mobx';
import { observer } from 'mobx-react';

import destinations from './destinations';

import * as colors from './colors';
import * as stylers from './stylers';
import Button from './ui/Button';
import Field from './ui/Field';
import Choice from './ui/Choice';
import IngredientsEditor from './sections/IngredientsEditor';
import PreviewSection from './sections/preview';

import createObservableState from './state';

export default observer(React.createClass({
	getDefaultProps: function getDefaultProps() {
		return {
			showTree: false,
			initialDestinationID: 'foundation',
			initialDestinationDevice: 'phone',
			initialScenarios: [{}],
			initialActiveScenarioIndex: 0
		};
	},
	componentWillMount: function componentWillMount() {
		var _this = this;

		var _props = this.props,
		    content = _props.initialContent,
		    allIngredients = _props.initialIngredients,
		    destinationID = _props.initialDestinationID,
		    destinationDevice = _props.initialDestinationDevice,
		    scenarios = _props.initialScenarios,
		    activeScenarioIndex = _props.initialActiveScenarioIndex;


		createObservableState.call(this, {
			content: content,
			allIngredients: allIngredients,
			scenarios: scenarios,
			activeScenarioIndex: activeScenarioIndex,
			destinationID: destinationID,
			destinationDevice: destinationDevice
		});

		this.onSourceChange = action(function (content) {
			_this.content = content;
			if (_this.props.onChange) {
				_this.props.onChange({ content: content });
			}
		});
		this.onChangeDestination = action(function (newDestinationID) {
			_this.destinationID = newDestinationID;
			if (_this.props.onChange) {
				_this.props.onChange({ destinationID: destinationID });
			}
		});
		this.onPhoneDestination = action(function () {
			_this.destinationDevice = 'phone';
		});
		this.onFullDestination = action(function () {
			_this.destinationDevice = 'full';
		});

		this.changeAutorunDisposer = autorunAsync(function () {
			if (!_this.props.onChange) {
				return;
			}

			var content = _this.content,
			    contentTree = _this.contentTree,
			    allIngredients = _this.allIngredients,
			    destinationID = _this.destinationID,
			    destinationDevice = _this.destinationDevice;


			_this.props.onChange({
				content: content,
				contentTree: contentTree,
				allIngredients: allIngredients,
				destinationID: destinationID,
				destinationDevice: destinationDevice
			});
		});
	},
	componentWillUnmount: function componentWillUnmount() {
		this.changeAutorunDisposer();
		this.changeAutorunDisposer = null;
	},
	onClickDrag: function onClickDrag(_ref) {
		var type = _ref.type,
		    currentTarget = _ref.currentTarget,
		    target = _ref.target,
		    clientX = _ref.clientX;

		if (type == 'mouseup') {
			this.dragging = false;
		} else if (this.dragging || type == 'mousedown') {
			if (type == 'mousemove') {
				currentTarget.scrollLeft += this.mouseX - clientX;
			}

			if (type == 'mouseup') {
				this.dragging = false;
			} else {
				// Only allow clicking on background
				if (target.tagName == 'DIV') {
					this.dragging = true;
					this.mouseX = clientX;
				}
			}
		}
	},
	render: function render() {
		var showTree = this.props.showTree;
		var content = this.content,
		    contentTree = this.contentTree,
		    allIngredients = this.allIngredients,
		    activeIngredients = this.activeIngredients,
		    scenarios = this.scenarios,
		    activeScenarioIndex = this.activeScenarioIndex,
		    destinationID = this.destinationID,
		    destinationDevice = this.destinationDevice;


		var scenario = scenarios[activeScenarioIndex];

		console.dir(scenario);
		console.dir(contentTree);
		console.dir(activeIngredients);

		return React.createElement(
			Seed,
			{ row: true, justifyContent: 'center',
				grow: 0, shrink: 0,
				background: { color: '#191919' }
			},
			React.createElement(
				Seed,
				{ row: true,
					grow: 1, shrink: 2,
					minWidth: 320,
					overflow: 'scroll',
					onMouseDown: this.onClickDrag,
					onMouseMove: this.onClickDrag,
					onMouseUp: this.onClickDrag
				},
				React.createElement(
					Seed,
					_extends({ column: true,
						grow: 1
					}, stylers.mainColumn),
					React.createElement(Field, _extends({
						value: content,
						onChange: this.onSourceChange
					}, stylers.sourceField))
				),
				React.createElement(
					Seed,
					{ column: true },
					React.createElement(IngredientsEditor, {
						ingredients: allIngredients,
						ingredientIDToVariationIndex: scenario,
						onAddNew: this.addNewIngredient,
						onRemoveAtIndex: this.onRemoveIngredientAtIndex,
						onAddVariationAtIndex: this.onAddVariationAtIndex
					})
				)
			),
			showTree && React.createElement(
				Seed,
				_extends({ row: true, grow: 1, shrink: 1
				}, stylers.preview),
				React.createElement(
					'pre',
					null,
					!!contentTree ? JSON.stringify(contentTree, null, 2) : null
				)
			),
			React.createElement(PreviewSection, {
				contentTree: contentTree,
				ingredients: activeIngredients,
				destinationID: destinationID,
				destinationDevice: destinationDevice,
				destinations: destinations,
				onChangeDestination: this.onChangeDestination,
				onPhoneDestination: this.onPhoneDestination,
				onFullDestination: this.onFullDestination
			})
		);
	}
}));
